@@ -301,6 +301,7 @@ pub fn op_name(op: u8) -> Result<&'static str, LangError> {
     let name = match op {
         ops::NOP => names::op::NOP,
         ops::HALT => names::op::HALT,
+        ops::EHALT => names::op::EHALT,
         ops::CALL_ADDR => names::op::CALL_ADDR,
         ops::CALL_REG => names::op::CALL_REG,
         ops::RET => names::op::RET,
@@ -521,6 +522,7 @@ pub fn op_desc(op: u8) -> Result<&'static str, LangError> {
     let name = match op {
         ops::NOP => names::full::NOP,
         ops::HALT => names::full::HALT,
+        ops::EHALT => names::full::EHALT,
         ops::CALL_ADDR => names::full::CALL_ADDR,
         ops::CALL_REG => names::full::CALL_REG,
         ops::RET => names::full::RET,
